@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.8.4   2015/08/06
+ * Version: 0.1.15   2015/08/06
  */
 
 #ifndef _LINUX_LSM2CAITSITH_H
@@ -14,11 +14,12 @@
 
 #ifdef CONFIG_CAITSITH
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 7, 0)
+int ccs_settime(const struct timespec64 *ts, const struct timezone *tz);
+#else
 int ccs_settime(const struct timespec *ts, const struct timezone *tz);
-int ccs_sb_mount(const char *dev_name, struct path *path, const char *type,
-		 unsigned long flags, void *data);
+#endif
 int ccs_sb_umount(struct vfsmount *mnt, int flags);
-int ccs_sb_pivotroot(struct path *old_path, struct path *new_path);
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(4, 1, 0)
 int ccs_inode_getattr(struct vfsmount *mnt, struct dentry *dentry);
@@ -35,30 +36,62 @@ int ccs_socket_connect(struct socket *sock, struct sockaddr *address,
 		       int addrlen);
 int ccs_socket_listen(struct socket *sock, int backlog);
 int ccs_socket_sendmsg(struct socket *sock, struct msghdr *msg, int size);
-int ccs_path_unlink(struct path *dir, struct dentry *dentry);
-int ccs_path_mkdir(struct path *dir, struct dentry *dentry, umode_t mode);
-int ccs_path_rmdir(struct path *dir, struct dentry *dentry);
-int ccs_path_mknod(struct path *dir, struct dentry *dentry, umode_t mode,
-		   unsigned int dev);
-int ccs_path_truncate(struct path *path);
-int ccs_path_symlink(struct path *dir, struct dentry *dentry,
-		     const char *old_name);
-int ccs_path_link(struct dentry *old_dentry, struct path *new_dir,
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 7, 0)
+int ccs_path_chmod(const struct path *path, umode_t mode);
+int ccs_path_chown(const struct path *path, kuid_t uid, kgid_t gid);
+int ccs_path_chroot(const struct path *path);
+int ccs_path_link(struct dentry *old_dentry, const struct path *new_dir,
 		  struct dentry *new_dentry);
-int ccs_path_rename(struct path *old_dir, struct dentry *old_dentry,
-		    struct path *new_dir, struct dentry *new_dentry);
+int ccs_path_mkdir(const struct path *dir, struct dentry *dentry,
+		   umode_t mode);
+int ccs_path_mknod(const struct path *dir, struct dentry *dentry, umode_t mode,
+		   unsigned int dev);
+int ccs_path_rename(const struct path *old_dir, struct dentry *old_dentry,
+		    const struct path *new_dir, struct dentry *new_dentry);
+int ccs_path_rmdir(const struct path *dir, struct dentry *dentry);
+int ccs_path_symlink(const struct path *dir, struct dentry *dentry,
+		     const char *old_name);
+int ccs_path_truncate(const struct path *path);
+int ccs_path_unlink(const struct path *dir, struct dentry *dentry);
+int ccs_sb_mount(const char *dev_name, const struct path *path,
+		 const char *type, unsigned long flags, void *data);
+int ccs_sb_pivotroot(const struct path *old_path, const struct path *new_path);
+#else
 int ccs_path_chmod(struct path *path, umode_t mode);
 int ccs_path_chown(struct path *path, kuid_t uid, kgid_t gid);
 int ccs_path_chroot(struct path *path);
-
+int ccs_path_link(struct dentry *old_dentry, struct path *new_dir,
+		  struct dentry *new_dentry);
+int ccs_path_mkdir(struct path *dir, struct dentry *dentry, umode_t mode);
+int ccs_path_mknod(struct path *dir, struct dentry *dentry, umode_t mode,
+		   unsigned int dev);
+int ccs_path_rename(struct path *old_dir, struct dentry *old_dentry,
+		    struct path *new_dir, struct dentry *new_dentry);
+int ccs_path_rmdir(struct path *dir, struct dentry *dentry);
+int ccs_path_symlink(struct path *dir, struct dentry *dentry,
+		     const char *old_name);
+int ccs_path_truncate(struct path *path);
+int ccs_path_unlink(struct path *dir, struct dentry *dentry);
+int ccs_sb_mount(const char *dev_name, struct path *path, const char *type,
+		 unsigned long flags, void *data);
+int ccs_sb_pivotroot(struct path *old_path, struct path *new_path);
+#endif
 #else
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 7, 0)
+static inline int ccs_settime(const struct timespec64 *ts,
+			      const struct timezone *tz)
+{
+	return 0;
+}
+#else
 static inline int ccs_settime(const struct timespec *ts,
 			      const struct timezone *tz)
 {
 	return 0;
 }
-static inline int ccs_sb_mount(const char *dev_name, struct path *path,
+#endif
+static inline int ccs_sb_mount(const char *dev_name, const struct path *path,
 			       const char *type, unsigned long flags,
 			       void *data)
 {
@@ -68,8 +101,8 @@ static inline int ccs_sb_umount(struct vfsmount *mnt, int flags)
 {
 	return 0;
 }
-static inline int ccs_sb_pivotroot(struct path *old_path,
-				   struct path *new_path)
+static inline int ccs_sb_pivotroot(const struct path *old_path,
+				   const struct path *new_path)
 {
 	return 0;
 }
@@ -123,55 +156,57 @@ static inline int ccs_socket_sendmsg(struct socket *sock, struct msghdr *msg,
 {
 	return 0;
 }
-static inline int ccs_path_unlink(struct path *dir, struct dentry *dentry)
+static inline int ccs_path_unlink(const struct path *dir,
+				  struct dentry *dentry)
 {
 	return 0;
 }
-static inline int ccs_path_mkdir(struct path *dir, struct dentry *dentry,
+static inline int ccs_path_mkdir(const struct path *dir, struct dentry *dentry,
 				 umode_t mode)
 {
 	return 0;
 }
-static inline int ccs_path_rmdir(struct path *dir, struct dentry *dentry)
+static inline int ccs_path_rmdir(const struct path *dir, struct dentry *dentry)
 {
 	return 0;
 }
-static inline int ccs_path_mknod(struct path *dir, struct dentry *dentry,
+static inline int ccs_path_mknod(const struct path *dir, struct dentry *dentry,
 				 umode_t mode, unsigned int dev)
 {
 	return 0;
 }
-static inline int ccs_path_truncate(struct path *path)
+static inline int ccs_path_truncate(const struct path *path)
 {
 	return 0;
 }
-static inline int ccs_path_symlink(struct path *dir, struct dentry *dentry,
-				   const char *old_name)
+static inline int ccs_path_symlink(const struct path *dir,
+				   struct dentry *dentry, const char *old_name)
 {
 	return 0;
 }
 static inline int ccs_path_link(struct dentry *old_dentry,
-				struct path *new_dir,
+				const struct path *new_dir,
 				struct dentry *new_dentry)
 {
 	return 0;
 }
-static inline int ccs_path_rename(struct path *old_dir,
+static inline int ccs_path_rename(const struct path *old_dir,
 				  struct dentry *old_dentry,
-				  struct path *new_dir,
+				  const struct path *new_dir,
 				  struct dentry *new_dentry)
 {
 	return 0;
 }
-static inline int ccs_path_chmod(struct path *path, umode_t mode)
+static inline int ccs_path_chmod(const struct path *path, umode_t mode)
 {
 	return 0;
 }
-static inline int ccs_path_chown(struct path *path, kuid_t uid, kgid_t gid)
+static inline int ccs_path_chown(const struct path *path, kuid_t uid,
+				 kgid_t gid)
 {
 	return 0;
 }
-static inline int ccs_path_chroot(struct path *path)
+static inline int ccs_path_chroot(const struct path *path)
 {
 	return 0;
 }
