@@ -777,8 +777,14 @@ bool cs_dump_page(struct linux_binprm *bprm, unsigned long pos,
 	}
 	/* Same with get_arg_page(bprm, pos, 0) in fs/exec.c */
 #ifdef CONFIG_MMU
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 6, 0)
+	if (get_user_pages_remote(current, bprm->mm, pos, 1, 0, 1, &page,
+				  NULL) <= 0)
+		return false;
+#else
 	if (get_user_pages(current, bprm->mm, pos, 1, 0, 1, &page, NULL) <= 0)
 		return false;
+#endif
 #else
 	page = bprm->page[pos / PAGE_SIZE];
 #endif
